#ifndef REMOVE_SOURCE_RMDIR_H
#define REMOVE_SOURCE_RMDIR_H

/*******************************************************************************
*******************************************************************************/
#define REMOVE_SOURCE_RMDIR \
{\
	if(cpinfo->src_para == DEFAULT)\
	{\
		errno = 0;\
		if(rmdir(cpinfo->src) == -1)\
		{\
			if((errno != ENOTEMPTY) && (errno != ENOENT))\
			{\
				print_error("rmdir", __FILE__, __LINE__, cpdd);\
				fprintf(stderr, "error : %s\n", cpinfo->src);\
			}\
		}\
		else \
		{\
			cpinfo->src_para = REMOVE;\
		}\
	}\
}

#endif
